# Example Package

[GetHub Project](https://github.com/DrSudoSaeed/)

Library to search and download your favorite songs in the best quality :)

This library is always updated. Wait for new versions soon!

To use, install the library according to the instructions!

**Follow the steps below to use:**

```

from SearchMusic import *

search("آرون+افشار")  # Replace the music name with fast

download("https://music-fa.com/download-song/50970/")

# To download, just copy one of the links it gave you when searching for the song and paste it here

```